.. image:: https://raw.github.com/kunitoki/django-custard/master/custard-logo.png
   :alt: Django Custard
   :target: https://github.com/kunitoki/django-custard

==================================
Django runtime typed custom fields
==================================

Django Custard is a small reusable unobtrusive `Django <http://www.djangoproject.com>`_
app that implements runtime custom fields that can be attached to any model on the
fly: it's possible to create fields and set values for them from the code or
manage them through the admin site, with the ability to display them even outside
of the admin.

.. |pypi| image:: https://img.shields.io/pypi/v/django-custard.svg
   :alt: Pypi latest version
   :target: https://pypi.python.org/pypi/django-custard/

.. |travis| image:: https://img.shields.io/travis/kunitoki/django-custard.svg
   :alt: Build Status - master branch
   :target: https://travis-ci.org/kunitoki/django-custard

.. |coveralls| image:: https://img.shields.io/coveralls/kunitoki/django-custard.svg
   :alt: Source code coverage - master branch
   :target: https://coveralls.io/r/kunitoki/django-custard

.. |requirements| image:: https://img.shields.io/requires/github/kunitoki/django-custard.svg
    :alt: Python requirements
    :target: https://pypi.python.org/pypi/django-custard/

.. |downloads| image:: https://img.shields.io/pypi/dm/django-custard.svg
   :alt: Pypi downloads
   :target: https://pypi.python.org/pypi/django-custard/

.. |license| image:: https://img.shields.io/pypi/l/django-custard.svg
    :target: https://pypi.python.org/pypi/django-custard/
    :alt: License

|pypi| |travis| |coveralls| |requirements| |downloads| |license|

* Home page: https://github.com/kunitoki/django-custard
* Documentation: http://django-custard.readthedocs.org
* Pypi: https://pypi.python.org/pypi/django-custard
* Example app on Github: https://github.com/kunitoki/django-custard/example
* Changelog: `Changelog.rst <https://github.com/kunitoki/django-custard/blob/master/CHANGELOG.rst>`_
* License: `The MIT License (MIT) <http://opensource.org/licenses/MIT>`_
* Supports: Django 1.6, 1.7, 1.8 - Python 2.7, 3.2, 3.3, 3.4
